Welcome to pymf6's documentation!
=================================

.. toctree::
   :glob:
   :maxdepth: 1

   readme.rst
   principle.md
   Interactive
   examples/head_controlled_well/Head_Controlled_Well

.. examples.rst
.. binder.rst
.. developer.rst
.. changelog.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
